@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2019 University of California
+// Copyright (C) 2022 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -152,7 +152,8 @@ static void handle_get_project_status(GUI_RPC_CONN& grc) {
 
 static void handle_get_disk_usage(GUI_RPC_CONN& grc) {
     unsigned int i;
-    double size, boinc_non_project, d_allowed, boinc_total;
+    double size, boinc_non_project, d_allowed;
+//    double boinc_total;
 
     grc.mfout.printf("<disk_usage_summary>\n");
     int retval = get_filesystem_info(
@@ -184,7 +185,7 @@ static void handle_get_disk_usage(GUI_RPC_CONN& grc) {
         }
     }
 #endif
-    boinc_total = boinc_non_project;
+//    boinc_total = boinc_non_project;
     gstate.get_disk_usages();
     for (i=0; i<gstate.projects.size(); i++) {
         PROJECT* p = gstate.projects[i];
@@ -195,7 +196,7 @@ static void handle_get_disk_usage(GUI_RPC_CONN& grc) {
             "</project>\n",
             p->master_url, p->disk_usage
         );
-        boinc_total += p->disk_usage;
+//        boinc_total += p->disk_usage;
     }
     d_allowed = gstate.allowed_disk_usage(gstate.total_disk_usage);
     grc.mfout.printf(
@@ -1095,7 +1096,14 @@ static void handle_acct_mgr_rpc_poll(GUI_RPC_CONN& grc) {
 
 static void handle_get_newer_version(GUI_RPC_CONN& grc) {
     gstate.new_version_check(true);
-
+    // this initiates an RPC to get version info.
+    // Wait for it to finish.
+    //
+    while (gstate.get_current_version_op.gui_http->gui_http_state != HTTP_STATE_IDLE) {
+        if (!gstate.poll_slow_events()) {
+            gstate.do_io_or_sleep(1.0);
+        }
+    }
     grc.mfout.printf(
         "<newer_version>%s</newer_version>\n"
         "<download_url>%s</download_url>\n",
@@ -1865,7 +1873,7 @@ static int handle_rpc_aux(GUI_RPC_CONN& grc) {
     int retval = 0;
     grc.mfin.init_buf_read(grc.request_msg);
     if (grc.xp.get_tag()) {    // parse <boinc_gui_rpc_request>
-        grc.mfout.printf("<error>missing boing_gui_rpc_request tag</error>\n");
+        grc.mfout.printf("<error>missing boinc_gui_rpc_request tag</error>\n");
         return 0;
     }
     if (grc.xp.get_tag()) {    // parse the request tag
